Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(946)

Unified Diff: content/public/renderer/render_frame.h

Issue 2844063003: Migrate RenderFrameImpl to use BinderRegistry. (Closed)
Patch Set: . Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/renderer/render_frame.h
diff --git a/content/public/renderer/render_frame.h b/content/public/renderer/render_frame.h
index 4202f0dd5a30f1a82fe0054d6047978518f98ca2..68992bd43234af805b06887c111fa2f15a2d35f2 100644
--- a/content/public/renderer/render_frame.h
+++ b/content/public/renderer/render_frame.h
@@ -38,7 +38,7 @@ class Size;
}
namespace service_manager {
-class InterfaceRegistry;
+class BinderRegistry;
class InterfaceProvider;
}
@@ -156,9 +156,9 @@ class CONTENT_EXPORT RenderFrame : public IPC::Listener,
// Return true if this frame is hidden.
virtual bool IsHidden() = 0;
// Returns the InterfaceRegistry that this process uses to expose interfaces
// to the application running in this frame.
- virtual service_manager::InterfaceRegistry* GetInterfaceRegistry() = 0;
+ virtual service_manager::BinderRegistry* GetInterfaceRegistry() = 0;
// Returns the InterfaceProvider that this process can use to bind
// interfaces exposed to it by the application running in this frame.
@@ -156,9 +156,9 @@ class CONTENT_EXPORT RenderFrame : public IPC::Listener,
// Return true if this frame is hidden.
virtual bool IsHidden() = 0;
- // Returns the InterfaceRegistry that this process uses to expose interfaces
+ // Returns the BinderRegistry that this process uses to expose interfaces
// to the application running in this frame.

Powered by Google App Engine
This is Rietveld 408576698